@@ -1,6 +1,7 @@
 package Catmandu::Fix::marc_set;
 
 use Catmandu::Sane;
+use Catmandu::Util qw(:is);
 use Carp qw(confess);
 use Moo;
 use Catmandu::Fix::Has;
@@ -12,7 +13,6 @@ has record         => (fix_opt => 1);
 sub emit {
     my ($self,$fixer) = @_;
     my $record_key  = $fixer->emit_string($self->record // 'record');
-    my $value       = $fixer->emit_string($self->value);
     my $marc_path   = $self->marc_path;
 
     my $field_regex;
@@ -36,16 +36,39 @@ sub emit {
         confess "invalid marc path";
     }
 
+    my $perl = "";
+
+    # Find out if we need to insert a literal value or a value from a JSON path
+    my $value;
+
+    if ($self->value =~ /^\$\.(\S+)$/) {
+        my $path = $fixer->split_path($1);
+        my $key  = pop @$path;
+        $value =  $fixer->generate_var;
+        $perl .= $fixer->emit_declare_vars($value, '""');
+        $perl .= $fixer->emit_walk_path($fixer->var, $path, sub {
+            my $var = shift;
+            $fixer->emit_get_key($var, $key, sub {
+                my $var = shift;
+                "${value} = ${var};";
+            });
+        });
+    }
+    else {
+        $value = $fixer->emit_string($self->value);
+    }
+    ##############
+
     $field_regex = $field;
     $field_regex =~ s/\*/./g;
 
     my $var  = $fixer->var;
-    my $perl = "";
 
     $perl .= $fixer->emit_foreach("${var}->{${record_key}}", sub {
         my $var  = shift;
         my $perl = "";
 
+        $perl .= "next unless is_value ${value};";
         $perl .= "next if ${var}->[0] !~ /${field_regex}/;";
 
         if (defined $ind1) {
@@ -114,6 +137,9 @@ Catmandu::Fix::marc_set - set a marc value of one (sub)field to a new value
     # Set the 100-a subfield where indicator-1 is 3
     marc_set('100[3]a','Farquhar family.')
 
+    # Copy data from another field in a subfield
+    marc_set('100a','$.my.deep.field')
+
 =head1 DESCRIPTION
 
 Read our Wiki pages at L<https://github.com/LibreCat/Catmandu/wiki/Fixes> for a complete
