@@ -73,6 +73,8 @@ Type describes the MARC parser to be used. Currently we support:
 
 =item USMARC    L<Catmandu::Importer::MARC::USMARC>
 
+=item ISO       alias for USMARC
+
 =item MicroLIF  L<Catmandu::Importer::MARC::MicroLIF>
 
 =item MARCMaker L<Catmandu::Importer::MARC::MARCMaker>
@@ -115,12 +117,14 @@ use Catmandu::Util;
 use Moo;
 
 has type           => (is => 'ro' , default => sub { 'USMARC' });
-has _importer      => (is => 'ro' , lazy => 1 , builder => '_build_importer' , handles => 'Catmandu::Importer');
+has _importer      => (is => 'ro' , lazy => 1 , builder => '_build_importer' , handles => ['generator']);
 has _importer_args => (is => 'rwp', writer => '_set_importer_args');
 
+with 'Catmandu::Importer';
+
 sub _build_importer {
     my ($self) = @_;
-    my $type = $self->type;
+    my $type = $self->type eq 'ISO' ? 'USMARC' : $self->type;
 
     $type = 'Record' if exists $self->_importer_args->{records};
     
